pub struct MetaDataUpdateMsg {
pub description: Option<String>,
pub image: Option<String>,
pub accounts: Option<Vec<Account>>,
pub websites: Option<Vec<Website>>,
}Fields
description: Option<String>image: Option<String>accounts: Option<Vec<Account>>websites: Option<Vec<Website>>Trait Implementations
Sourceimpl Clone for MetaDataUpdateMsg
impl Clone for MetaDataUpdateMsg
Sourcefn clone(&self) -> MetaDataUpdateMsg
fn clone(&self) -> MetaDataUpdateMsg
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetaDataUpdateMsg
impl Debug for MetaDataUpdateMsg
Sourceimpl<'de> Deserialize<'de> for MetaDataUpdateMsg
impl<'de> Deserialize<'de> for MetaDataUpdateMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MetaDataUpdateMsg
impl JsonSchema for MetaDataUpdateMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MetaDataUpdateMsg
impl PartialEq for MetaDataUpdateMsg
Sourceimpl Serialize for MetaDataUpdateMsg
impl Serialize for MetaDataUpdateMsg
impl StructuralPartialEq for MetaDataUpdateMsg